@@ -18,6 +18,7 @@ import time
 import statistics
 
 import cv2
+import numpy as np
 import requests
 
 from pyxllib.prog.newbie import round_int
@@ -39,9 +40,21 @@ def __1_转类labelme标注():
 def loc2points(loc, ratio=1):
     """ 百度的location格式转为 {'points': [[a, b], [c, d]], 'shape_type: 'rectangle'} """
     # 目前关注到的都是矩形，不知道有没可能有其他格式
-    l, t, r, b = xywh2ltrb([loc['left'], loc['top'], loc['width'], loc['height']])
+    ltrb = xywh2ltrb([loc['left'], loc['top'], loc['width'], loc['height']])
     if ratio != 1:
-        l, t, r, b = [round_int(x * ratio) for x in [l, t, r, b]]
+        ltrb = [x * ratio for x in ltrb]
+    l, t, r, b = round_int(ltrb, ndim=1)
+    return {'points': [[l, t], [r, b]],
+            'shape_type': 'rectangle'}
+
+
+def loc2points2(loc, ratio=1):
+    """ 百度的location格式转为 {'points': [[a, b], [c, d]], 'shape_type: 'rectangle'} """
+    # 目前关注到的都是矩形，不知道有没可能有其他格式
+    ltrb = xywh2ltrb([loc['left'], loc['top'], loc['right'] - loc['left'], loc['bottom'] - loc['top']])
+    if ratio != 1:
+        ltrb = [x * ratio for x in ltrb]
+    l, t, r, b = round_int(ltrb, ndim=1)
     return {'points': [[l, t], [r, b]],
             'shape_type': 'rectangle'}
 
@@ -158,14 +171,14 @@ def __2_定制不同输出格式():
     pass
 
 
-class XlAiClientBase:
+class XlAiClient:
     """
     封装该类
         目的1：合并输入文件和url的识别
         目的2：带透明底的png百度api识别不了，要先转成RGB格式
     """
 
-    def __init__(self, auto_setup=True):
+    def __init__(self, auto_setup=True, check=True):
         # 1 默认值
         self.db = None
 
@@ -184,7 +197,7 @@ class XlAiClientBase:
             if 'mathpix' in accounts:
                 self.login_mathpix(**accounts['mathpix'])
             if 'priu' in accounts:
-                self.login_priu(**accounts['priu'])
+                self.login_priu(**accounts['priu'], check=check)
 
     def __A1_登录账号(self):
         pass
@@ -211,7 +224,7 @@ class XlAiClientBase:
         self._mathpix_header = {'Content-type': 'application/json'}
         self._mathpix_header.update({'app_id': app_id, 'app_key': app_key})
 
-    def login_priu(self, token, host=None):
+    def login_priu(self, token, host=None, *, check=True):
         """ 福建省模式识别与图像理解重点实验室
 
         :param str|list[str] host:
@@ -231,20 +244,23 @@ class XlAiClientBase:
         else:
             raise TypeError
 
-        connent = False
-        for host in hosts:
-            try:
-                if '欢迎来到 厦门理工' in requests.get(f'http://{host}/home', timeout=5).text:
-                    self._priu_host = host
-                    connent = True
-                    break
-            except requests.exceptions.ConnectionError:
-                continue
+        if check:
+            connent = False
+            for host in hosts:
+                try:
+                    if '欢迎来到 厦门理工' in requests.get(f'http://{host}/home', timeout=5).text:
+                        self._priu_host = host
+                        connent = True
+                        break
+                except requests.exceptions.ConnectionError:
+                    continue
 
-        if not connent:
-            raise ConnectionError('PRIU接口登录失败')
-
-        return connent
+            if not connent:
+                raise ConnectionError('PRIU接口登录失败')
+            return connent
+        else:
+            self._priu_host = hosts[0]  # 不检查的场景，一般都是局域网内使用
+            return None
 
     def __A2_调整图片和关联数据库(self):
         pass
@@ -301,73 +317,73 @@ class XlAiClientBase:
     def __B1_通用(self):
         pass
 
-    def general(self, im, options=None):
+    def general(self, image, options=None):
         """ 通用文字识别（标准含位置版）: https://cloud.baidu.com/doc/OCR/s/vk3h7y58v
         500次/天赠送 + 超出按量计费
 
         注意只要ratio!=1涉及到缩放的，偏移误差是会变大的~~
         """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(imageage)
         result_dict = self.run_with_db(self._aipocr.general, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def basicGeneral(self, im, options=None):
+    def basicGeneral(self, image, options=None):
         """ 通用文字识别（标准版）: https://cloud.baidu.com/doc/OCR/s/zk3h7xz52
         5万次/天赠送 + 超出按量计费
         """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.basicGeneral, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def accurate(self, im, options=None):
+    def accurate(self, image, options=None):
         """ 通用文字识别（高精度含位置版）: https://cloud.baidu.com/doc/OCR/s/tk3h7y2aq """
         sz = 10 * 1024 ** 2
-        buffer, ratio = self.adjust_image(im, max_length=8192, limit_b64buffer_size=sz, to_buffer=True)
+        buffer, ratio = self.adjust_image(image, max_length=8192, limit_b64buffer_size=sz, to_buffer=True)
         result_dict = self.run_with_db(self._aipocr.accurate, buffer, options, save_buffer_threshold_size=sz)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def basicAccurate(self, im, options=None):
+    def basicAccurate(self, image, options=None):
         """ 通用文字识别（高精度版）: https://cloud.baidu.com/doc/OCR/s/1k3h7y3db """
         sz = 10 * 1024 ** 2
-        buffer, ratio = self.adjust_image(im, max_length=8192, limit_b64buffer_size=sz, to_buffer=True)
+        buffer, ratio = self.adjust_image(image, max_length=8192, limit_b64buffer_size=sz, to_buffer=True)
         result_dict = self.run_with_db(self._aipocr.basicAccurate, buffer, options, save_buffer_threshold_size=sz)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def webimageLoc(self, im, options=None):
+    def webimageLoc(self, image, options=None):
         """ 网络图片文字识别（含位置版）: https://cloud.baidu.com/doc/OCR/s/Nkaz574we """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.webimageLoc, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def webImage(self, im, options=None):
+    def webImage(self, image, options=None):
         """ 网络图片文字识别: https://cloud.baidu.com/doc/OCR/s/Sk3h7xyad """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.webImage, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def handwriting(self, im, options=None):
+    def handwriting(self, image, options=None):
         """ 手写文字识别: https://cloud.baidu.com/doc/OCR/s/hk3h7y2qq """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.handwriting, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def numbers(self, im, options=None):
+    def numbers(self, image, options=None):
         """ 数字识别: https://cloud.baidu.com/doc/OCR/s/Ok3h7y1vo """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.numbers, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def qrcode(self, im, options=None):
+    def qrcode(self, image, options=None):
         """ 二维码识别: https://cloud.baidu.com/doc/OCR/s/qk3h7y5o7 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.qrcode, buffer, options)
 
         ls = result_dict['codes_result']
@@ -381,7 +397,7 @@ class XlAiClientBase:
         del result_dict['codes_result_num']
         return result_dict
 
-    def form(self, im, options=None):
+    def form(self, image, options=None):
         """ 表格文字识别(同步接口): https://cloud.baidu.com/doc/OCR/s/ik3h7xyxf
 
         备注：
@@ -482,7 +498,7 @@ class XlAiClientBase:
 
         # 2 主体解析功能
 
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.form, buffer, options)
         shapes = []
         htmltables = []
@@ -500,16 +516,16 @@ class XlAiClientBase:
         del result_dict['forms_result_num']
         return result_dict
 
-    def doc_analysis_office(self, im, options=None):
+    def doc_analysis_office(self, image, options=None):
         """ 办公文档识别: https://cloud.baidu.com/doc/OCR/s/ykg9c09ji """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.doc_analysis_office, buffer, options)
         result_dict = ToLabelmeLike.list_word2(result_dict, 1 / ratio, 'results', 'results_num')
         return result_dict
 
-    def seal(self, im, options=None):
+    def seal(self, image, options=None):
         """ 印章识别: https://cloud.baidu.com/doc/OCR/s/Mk3h7y47a """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.seal, buffer, options)
 
         shapes = []
@@ -529,7 +545,7 @@ class XlAiClientBase:
     def __B2_卡证(self):
         pass
 
-    def idcard(self, im, options=None):
+    def idcard(self, image, options=None):
         """ 身份证识别: https://cloud.baidu.com/doc/OCR/s/rk3h7xzck """
 
         def idcard_front(image, options=None):
@@ -537,74 +553,74 @@ class XlAiClientBase:
                                        options.get('id_card_side', 'front'),  # 默认识别带照片一面
                                        options)
 
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(idcard_front, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result')
         return result_dict
 
-    def idcard_back(self, im, options=None):
+    def idcard_back(self, image, options=None):
         def func(image, options=None):
             return self._aipocr.idcard(image,
                                        options.get('id_card_side', 'back'),  # 识别国徽一面
                                        options)
 
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(func, buffer, options, mode_name='idcard_back')
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result')
         return result_dict
 
-    def bankcard(self, im, options=None):
+    def bankcard(self, image, options=None):
         """ 银行卡识别: https://cloud.baidu.com/doc/OCR/s/ak3h7xxg3 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.bankcard, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'result', 'words_result_num')
         return result_dict
 
-    def businessLicense(self, im, options=None):
+    def businessLicense(self, image, options=None):
         """ 营业执照识别: https://cloud.baidu.com/doc/OCR/s/sk3h7y3zs """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.businessLicense, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def businessCard(self, im, options=None):
+    def businessCard(self, image, options=None):
         """ 名片识别: https://cloud.baidu.com/doc/OCR/s/5k3h7xyi2 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.businessCard, buffer, options)
         result_dict = ToLabelmeLike.dict_strs(result_dict, 1 / ratio, 'words_result')
         return result_dict
 
-    def passport(self, im, options=None):
+    def passport(self, image, options=None):
         """ 护照识别: https://cloud.baidu.com/doc/OCR/s/Wk3h7y1gi """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.passport, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def HKMacauExitentrypermit(self, im, options=None):
+    def HKMacauExitentrypermit(self, image, options=None):
         """ 港澳通行证识别: https://cloud.baidu.com/doc/OCR/s/4k3h7y0ly """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.HKMacauExitentrypermit, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def taiwanExitentrypermit(self, im, options=None):
+    def taiwanExitentrypermit(self, image, options=None):
         """ 台湾通行证识别: https://cloud.baidu.com/doc/OCR/s/kk3h7y2yc """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.taiwanExitentrypermit, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def householdRegister(self, im, options=None):
+    def householdRegister(self, image, options=None):
         """ 户口本识别: https://cloud.baidu.com/doc/OCR/s/ak3h7xzk7 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.householdRegister, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def birthCertificate(self, im, options=None):
+    def birthCertificate(self, image, options=None):
         """ 出生医学证明识别: https://cloud.baidu.com/doc/OCR/s/mk3h7y1o6 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.birthCertificate, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
@@ -612,23 +628,23 @@ class XlAiClientBase:
     def __B3_交通(self):
         pass
 
-    def vehicleLicense(self, im, options=None):
+    def vehicleLicense(self, image, options=None):
         """ 行驶证识别: https://cloud.baidu.com/doc/OCR/s/yk3h7y3ks """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.vehicleLicense, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def drivingLicense(self, im, options=None):
+    def drivingLicense(self, image, options=None):
         """ 驾驶证识别: https://cloud.baidu.com/doc/OCR/s/Vk3h7xzz7 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.drivingLicense, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def licensePlate(self, im, options=None):
+    def licensePlate(self, image, options=None):
         """ 车牌识别: https://cloud.baidu.com/doc/OCR/s/ck3h7y191 """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.licensePlate, buffer, options)
 
         d = result_dict['words_result']
@@ -646,30 +662,30 @@ class XlAiClientBase:
         del result_dict['words_result']
         return result_dict
 
-    def vinCode(self, im, options=None):
+    def vinCode(self, image, options=None):
         """ VIN码识别: https://cloud.baidu.com/doc/OCR/s/zk3h7y51e """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.vinCode, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def vehicleInvoice(self, im, options=None):
+    def vehicleInvoice(self, image, options=None):
         """ 机动车销售发票识别: https://cloud.baidu.com/doc/OCR/s/vk3h7y4tx """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.vehicleInvoice, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def vehicleCertificate(self, im, options=None):
+    def vehicleCertificate(self, image, options=None):
         """ 车辆合格证识别: https://cloud.baidu.com/doc/OCR/s/yk3h7y3sc """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.vehicleCertificate, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def raw_mixed_multi_vehicle(self, im, options=None):
+    def raw_mixed_multi_vehicle(self, image, options=None):
         """ 车辆证照混贴识别: https://cloud.baidu.com/doc/OCR/s/Kksfsbngb """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.mixed_multi_vehicle, buffer, options)
 
         if ratio != 1:
@@ -678,8 +694,8 @@ class XlAiClientBase:
 
         return result_dict
 
-    def mixed_multi_vehicle(self, im, options=None):
-        result_dict = self.raw_mixed_multi_vehicle(im, options)
+    def mixed_multi_vehicle(self, image, options=None):
+        result_dict = self.raw_mixed_multi_vehicle(image, options)
 
         shapes = []
         for x in result_dict['words_result']:
@@ -696,16 +712,16 @@ class XlAiClientBase:
         del result_dict['words_result_num']
         return result_dict
 
-    def vehicle_registration_certificate(self, im, options=None):
+    def vehicle_registration_certificate(self, image, options=None):
         """ 机动车登记证书识别: https://cloud.baidu.com/doc/OCR/s/qknzs5zzo """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.vehicle_registration_certificate, buffer, options)
         result_dict = ToLabelmeLike.dict_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def weightNote(self, im, options=None):
+    def weightNote(self, image, options=None):
         """ 磅单识别: https://cloud.baidu.com/doc/OCR/s/Uksfp9far """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.weightNote, buffer, options)
 
         shapes = []
@@ -723,9 +739,9 @@ class XlAiClientBase:
     def __B4_财务(self):
         pass
 
-    def multipleInvoice(self, im, options=None):
+    def multipleInvoice(self, image, options=None):
         """ 智能财务票据识别: https://cloud.baidu.com/doc/OCR/s/7ktb8md0j """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.multipleInvoice, buffer, options)
 
         shapes = []
@@ -739,16 +755,16 @@ class XlAiClientBase:
         del result_dict['words_result_num']
         return result_dict
 
-    def quotaInvoice(self, im, options=None):
+    def quotaInvoice(self, image, options=None):
         """ 定额发票识别: https://cloud.baidu.com/doc/OCR/s/lk3h7y4ev """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.quotaInvoice, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def invoice(self, im, options=None):
+    def invoice(self, image, options=None):
         """ 通用机打发票识别: https://cloud.baidu.com/doc/OCR/s/Pk3h7y06q """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.invoice, buffer, options)
 
         shapes = []
@@ -765,34 +781,34 @@ class XlAiClientBase:
         del result_dict['words_result_num']
         return result_dict
 
-    def trainTicket(self, im, options=None):
+    def trainTicket(self, image, options=None):
         """ 火车票识别: https://cloud.baidu.com/doc/OCR/s/Ok3h7y35u """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.trainTicket, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def taxiReceipt(self, im, options=None):
+    def taxiReceipt(self, image, options=None):
         """ 出租车票识别: https://cloud.baidu.com/doc/OCR/s/Zk3h7xxnn """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.taxiReceipt, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def airTicket(self, im, options=None):
+    def airTicket(self, image, options=None):
         """ 飞机行程单识别: https://cloud.baidu.com/doc/OCR/s/Qk3h7xzro """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.airTicket, buffer, options)
         result_dict = ToLabelmeLike.dict_str(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def onlineTaxiItinerary(self, im, options=None):
+    def onlineTaxiItinerary(self, image, options=None):
         """ 网约车行程单识别: https://cloud.baidu.com/doc/OCR/s/Bkocoyu9n """
 
         def func(image, options=None):
             return self._aipocr.onlineTaxiItinerary(image)
 
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(func, buffer, options, mode_name='onlineTaxiItinerary')
 
         shapes = []
@@ -810,9 +826,9 @@ class XlAiClientBase:
         del result_dict['words_result_num']
         return result_dict
 
-    def receipt(self, im, options=None):
+    def receipt(self, image, options=None):
         """ receipt: https://cloud.baidu.com/doc/OCR/s/6k3h7y11b """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.receipt, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
@@ -820,30 +836,30 @@ class XlAiClientBase:
     def __B5_医疗(self):
         pass
 
-    def raw_medicalInvoice(self, im, options=None):
+    def raw_medicalInvoice(self, image, options=None):
         """ 医疗发票识别: https://cloud.baidu.com/doc/OCR/s/yke30j1hq """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.medicalInvoice, buffer, options)
         return result_dict
 
-    def raw_medicalDetail(self, im, options=None):
+    def raw_medicalDetail(self, image, options=None):
         """ 医疗费用明细识别: https://cloud.baidu.com/doc/OCR/s/Bknjnwlyj """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.medicalDetail, buffer, options)
         return result_dict
 
-    def raw_insuranceDocuments(self, im, options=None):
+    def raw_insuranceDocuments(self, image, options=None):
         """ 保险单识别: https://cloud.baidu.com/doc/OCR/s/Wk3h7y0eb """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.insuranceDocuments, buffer, options)
         return result_dict
 
     def __B6_教育(self):
         pass
 
-    def docAnalysis(self, im, options=None):
+    def docAnalysis(self, image, options=None):
         """ 试卷分析与识别: https://cloud.baidu.com/doc/OCR/s/jk9m7mj1l """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.docAnalysis, buffer, options)
 
         shapes = []
@@ -858,9 +874,9 @@ class XlAiClientBase:
         del result_dict['results_num']
         return result_dict
 
-    def formula(self, im, options=None):
+    def formula(self, image, options=None):
         """ 公式识别: https://cloud.baidu.com/doc/OCR/s/Ok3h7xxva """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.formula, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
@@ -868,21 +884,21 @@ class XlAiClientBase:
     def __B7_其他(self):
         pass
 
-    def meter(self, im, options=None):
+    def meter(self, image, options=None):
         """ 仪器仪表盘读数识别: https://cloud.baidu.com/doc/OCR/s/Jkafike0v """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.meter, buffer, options)
         result_dict = ToLabelmeLike.list_word(result_dict, 1 / ratio, 'words_result', 'words_result_num')
         return result_dict
 
-    def raw_facade(self, im, options=None):
+    def raw_facade(self, image, options=None):
         """ 门脸文字识别: https://cloud.baidu.com/doc/OCR/s/wk5hw3cvo """
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(self._aipocr.facade, buffer, options)
         return result_dict
 
-    def facade(self, im, options=None):
-        result_dict = self.raw_facade(im, options)
+    def facade(self, image, options=None):
+        result_dict = self.raw_facade(image, options)
 
         shapes = []
         for x in result_dict['words_result']:
@@ -897,7 +913,7 @@ class XlAiClientBase:
     def __C_其他三方库接口(self):
         pass
 
-    def mathpix_latex(self, im, options=None):
+    def mathpix_latex(self, image, options=None):
         """ 调用mathpix识别单张图片的公式
 
         【return】
@@ -931,7 +947,7 @@ class XlAiClientBase:
             return json.loads(r.text)
 
         # mathpix的接口没有说限制图片大小，但我还是按照百度的规范处理下更好
-        buffer, ratio = self.adjust_image(im)
+        buffer, ratio = self.adjust_image(image)
         result_dict = self.run_with_db(func, buffer, options, mode_name='mathpix_latex')
         result_dict['position'] = zoom_point(result_dict['position'], ratio)
         return result_dict
@@ -939,58 +955,107 @@ class XlAiClientBase:
     def __D_福建省模式识别与图像理解重点实验室(self):
         pass
 
-    def _priu_read_image(self, im):
+    def _priu_read_image(self, image):
         # 不进行尺寸、文件大小压缩，这样会由平台上负责进行ratio缩放计算
-        buffer, ratio = self.adjust_image(im,
+        buffer, ratio = self.adjust_image(image,
                                           min_length=None, max_length=None,
                                           limit_b64buffer_size=None,
                                           b64encode=True)
         assert ratio == 1, f'本地不做缩放，由服务器进行缩放处理'
         return buffer.decode()
 
-    def common_ocr(self, im):
-        data = {'image': self._priu_read_image(im)}
-        r = requests.post(f'http://{self._priu_host}/api/common_ocr', json.dumps(data), headers=self._priu_header)
-        res = json.loads(r.text)
-        return res
-
-    def hesuan_layout(self, im):
-        data = {'image': self._priu_read_image(im)}
-        r = requests.post(f'http://{self._priu_host}/api/hesuan_layout', json.dumps(data), headers=self._priu_header)
-        return json.loads(r.text)
-
-
-class XlAiClient(XlAiClientBase):
-    """ XlAiClientBase存放真实原始接口，这里XlAiClient会有些为了方便，做的二次解析接口 """
-
-    def priu_api(self, mode, im, options=None):
+    def priu_api(self, mode, image=None, texts=None, options=None, **kwargs):
         """ 借助服务器来调用该类中含有的其他函数接口
 
         使用该接口的时候，因为服务器一般会有图片等的备份，所以本接口默认不对图片进行备份
         另外因为可能会调用自定义的模型功能，自定义的模型可能迭代较快，不适合在数据库缓存结果，所以也不记录json结果
+
+        :param mode: 使用的api接口名称
+        :param image: image、texts、options都是比较常用的几个参数键值，所以显式地写出来
+        :param kwargs: 也可以自己额外扩展一些键值，兼容一些特殊的输入范式的api接口
         """
-        data = {'image': self._priu_read_image(im)}
+        # 1 统一输入参数的范式
+        data = {}
+        if image is not None:
+            data['image'] = self._priu_read_image(image)
+        if texts is not None:
+            data['texts'] = texts
         if options:
             data['options'] = options
+        if kwargs:
+            data.update(kwargs)
         r = requests.post(f'http://{self._priu_host}/api/{mode}', json.dumps(data), headers=self._priu_header)
-        return json.loads(r.text)
+        res = json.loads(r.text)
 
-    def ocr2texts(self, im, mode='common_ocr', options=None):
+        # 2 统一返回值的范式，默认都是dict。 有些特殊格式表示是图片，这里会自动做后处理解析。
+        if isinstance(res, dict) and len(res) == 1 and 'imageData' in res:
+            # 只有一张图片情况的数据，直接返回图片
+            return xlcv.read_from_buffer(res['imageData'], b64decode=True)
+        else:
+            return res
+
+    def common_ocr(self, image):
+        data = {'image': self._priu_read_image(image)}
+        r = requests.post(f'http://{self._priu_host}/api/common_ocr', json.dumps(data), headers=self._priu_header)
+        res = json.loads(r.text)
+        return res
+
+    def ocr2texts(self, image, mode='common_ocr', options=None):
         """ 通用的识别一张图的所有文本 """
         texts = []  # 因图片太小等各种原因，没有识别到结果，默认就设空值
         try:
-            d = self.priu_api(mode, im, options)
+            d = self.priu_api(mode, image, **options)
             if 'shapes' in d:
                 texts = [sp['label']['text'] for sp in d['shapes']]
         except requests.exceptions.ConnectionError:
             pass
         return texts
 
-    def rec_singleline(self, im, mode='common_ocr', options=None):
+    def rec_singleline(self, image, mode='common_ocr', options=None):
         """ 通用的识别一张图的所有文本，并拼接到一起 """
-        texts = self.ocr2texts(im, mode, options)
+        texts = self.ocr2texts(image, mode, **options)
         return ' '.join(texts)
 
+    def hesuan_layout(self, image):
+        data = {'image': self._priu_read_image(image)}
+        r = requests.post(f'http://{self._priu_host}/api/hesuan_layout', json.dumps(data), headers=self._priu_header)
+        return json.loads(r.text)
+
+    def lexical_analysis(self, texts, options=None, return_mode=None):
+        # TODO 可以增加接口参数，配置返回值类型。其他api同理。
+        data = {'texts': texts}
+        if options:
+            data['options'] = options
+        r = requests.post(f'http://{self._priu_host}/api/lac', json.dumps(data), headers=self._priu_header)
+        res = json.loads(r.text)
+
+        if return_mode == 'raw':
+            pass
+        else:
+            res = [x['word'] for x in res]
+        return res
+
+    def sentiment_classify(self, texts, options=None):
+        data = {'texts': texts}
+        if options:
+            data['options'] = options
+        r = requests.post(f'http://{self._priu_host}/api/senta_bilstm', json.dumps(data), headers=self._priu_header)
+        return json.loads(r.text)
+
+    def humanseg(self, image):
+        """ 人像抠图
+
+        TODO 还没测过特大、特小图会不会有问题~
+        """
+        im, _ = self.adjust_image(image, 1, to_buffer=False)  # 不能用xlcv.read，因为也可能作为服务端接口，输入buffer格式
+        mask = self.priu_api('deeplabv3p_xception65_humanseg', im)
+        new_im = np.concatenate([im, np.expand_dims(mask, axis=2)], axis=2)  # 变成BGRA格式图片
+        return new_im
+
+    def det_face(self, image):
+        lmdict = self.priu_api('ultra_light_fast_generic_face_detector_1mb_640', image)
+        return lmdict
+
 
 def demo_aipocr():
     from tqdm import tqdm
